// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_SIM_SSHR_2D_2OPIMM_TRACE_AARCH64_H_
#define VIXL_SIM_SSHR_2D_2OPIMM_TRACE_AARCH64_H_

const uint64_t kExpected_NEON_sshr_2D_2OPIMM[] = {
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0xffffffffffffffff, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000001,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000001, 0x0000000000000020,
  0x0000000000000000, 0x0000000000000010,
  0x0000000000000000, 0x0000000000000008,
  0x0000000000000000, 0x0000000000000004,
  0x0000000000000000, 0x0000000000000002,
  0x0000000000000000, 0x0000000000000001,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000020, 0x000000000000003e,
  0x0000000000000010, 0x000000000000001f,
  0x0000000000000008, 0x000000000000000f,
  0x0000000000000004, 0x0000000000000007,
  0x0000000000000002, 0x0000000000000003,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x000000000000003e, 0x000000000000003f,
  0x000000000000001f, 0x000000000000001f,
  0x000000000000000f, 0x000000000000000f,
  0x0000000000000007, 0x0000000000000007,
  0x0000000000000003, 0x0000000000000003,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x000000000000003f, 0x000000000000003f,
  0x000000000000001f, 0x000000000000001f,
  0x000000000000000f, 0x000000000000000f,
  0x0000000000000007, 0x0000000000000007,
  0x0000000000000003, 0x0000000000000003,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x000000000000003f, 0x0000000000003ffe,
  0x000000000000001f, 0x0000000000001fff,
  0x000000000000000f, 0x0000000000000fff,
  0x0000000000000007, 0x00000000000007ff,
  0x0000000000000003, 0x00000000000003ff,
  0x0000000000000001, 0x00000000000001ff,
  0x0000000000000000, 0x00000000000000ff,
  0x0000000000000000, 0x000000000000007f,
  0x0000000000000000, 0x000000000000003f,
  0x0000000000000000, 0x000000000000001f,
  0x0000000000000000, 0x000000000000000f,
  0x0000000000000000, 0x0000000000000007,
  0x0000000000000000, 0x0000000000000003,
  0x0000000000000000, 0x0000000000000001,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000003ffe, 0x0000000000003fff,
  0x0000000000001fff, 0x0000000000001fff,
  0x0000000000000fff, 0x0000000000000fff,
  0x00000000000007ff, 0x00000000000007ff,
  0x00000000000003ff, 0x00000000000003ff,
  0x00000000000001ff, 0x00000000000001ff,
  0x00000000000000ff, 0x00000000000000ff,
  0x000000000000007f, 0x000000000000007f,
  0x000000000000003f, 0x000000000000003f,
  0x000000000000001f, 0x000000000000001f,
  0x000000000000000f, 0x000000000000000f,
  0x0000000000000007, 0x0000000000000007,
  0x0000000000000003, 0x0000000000000003,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000003fff, 0x0000000000003fff,
  0x0000000000001fff, 0x0000000000001fff,
  0x0000000000000fff, 0x0000000000000fff,
  0x00000000000007ff, 0x00000000000007ff,
  0x00000000000003ff, 0x00000000000003ff,
  0x00000000000001ff, 0x00000000000001ff,
  0x00000000000000ff, 0x00000000000000ff,
  0x000000000000007f, 0x000000000000007f,
  0x000000000000003f, 0x000000000000003f,
  0x000000000000001f, 0x000000000000001f,
  0x000000000000000f, 0x000000000000000f,
  0x0000000000000007, 0x0000000000000007,
  0x0000000000000003, 0x0000000000000003,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000003fff, 0x000000003ffffffe,
  0x0000000000001fff, 0x000000001fffffff,
  0x0000000000000fff, 0x000000000fffffff,
  0x00000000000007ff, 0x0000000007ffffff,
  0x00000000000003ff, 0x0000000003ffffff,
  0x00000000000001ff, 0x0000000001ffffff,
  0x00000000000000ff, 0x0000000000ffffff,
  0x000000000000007f, 0x00000000007fffff,
  0x000000000000003f, 0x00000000003fffff,
  0x000000000000001f, 0x00000000001fffff,
  0x000000000000000f, 0x00000000000fffff,
  0x0000000000000007, 0x000000000007ffff,
  0x0000000000000003, 0x000000000003ffff,
  0x0000000000000001, 0x000000000001ffff,
  0x0000000000000000, 0x000000000000ffff,
  0x0000000000000000, 0x0000000000007fff,
  0x0000000000000000, 0x0000000000003fff,
  0x0000000000000000, 0x0000000000001fff,
  0x0000000000000000, 0x0000000000000fff,
  0x0000000000000000, 0x00000000000007ff,
  0x0000000000000000, 0x00000000000003ff,
  0x0000000000000000, 0x00000000000001ff,
  0x0000000000000000, 0x00000000000000ff,
  0x0000000000000000, 0x000000000000007f,
  0x0000000000000000, 0x000000000000003f,
  0x0000000000000000, 0x000000000000001f,
  0x0000000000000000, 0x000000000000000f,
  0x0000000000000000, 0x0000000000000007,
  0x0000000000000000, 0x0000000000000003,
  0x0000000000000000, 0x0000000000000001,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x000000003ffffffe, 0x000000003fffffff,
  0x000000001fffffff, 0x000000001fffffff,
  0x000000000fffffff, 0x000000000fffffff,
  0x0000000007ffffff, 0x0000000007ffffff,
  0x0000000003ffffff, 0x0000000003ffffff,
  0x0000000001ffffff, 0x0000000001ffffff,
  0x0000000000ffffff, 0x0000000000ffffff,
  0x00000000007fffff, 0x00000000007fffff,
  0x00000000003fffff, 0x00000000003fffff,
  0x00000000001fffff, 0x00000000001fffff,
  0x00000000000fffff, 0x00000000000fffff,
  0x000000000007ffff, 0x000000000007ffff,
  0x000000000003ffff, 0x000000000003ffff,
  0x000000000001ffff, 0x000000000001ffff,
  0x000000000000ffff, 0x000000000000ffff,
  0x0000000000007fff, 0x0000000000007fff,
  0x0000000000003fff, 0x0000000000003fff,
  0x0000000000001fff, 0x0000000000001fff,
  0x0000000000000fff, 0x0000000000000fff,
  0x00000000000007ff, 0x00000000000007ff,
  0x00000000000003ff, 0x00000000000003ff,
  0x00000000000001ff, 0x00000000000001ff,
  0x00000000000000ff, 0x00000000000000ff,
  0x000000000000007f, 0x000000000000007f,
  0x000000000000003f, 0x000000000000003f,
  0x000000000000001f, 0x000000000000001f,
  0x000000000000000f, 0x000000000000000f,
  0x0000000000000007, 0x0000000000000007,
  0x0000000000000003, 0x0000000000000003,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x000000003fffffff, 0x000000003fffffff,
  0x000000001fffffff, 0x000000001fffffff,
  0x000000000fffffff, 0x000000000fffffff,
  0x0000000007ffffff, 0x0000000007ffffff,
  0x0000000003ffffff, 0x0000000003ffffff,
  0x0000000001ffffff, 0x0000000001ffffff,
  0x0000000000ffffff, 0x0000000000ffffff,
  0x00000000007fffff, 0x00000000007fffff,
  0x00000000003fffff, 0x00000000003fffff,
  0x00000000001fffff, 0x00000000001fffff,
  0x00000000000fffff, 0x00000000000fffff,
  0x000000000007ffff, 0x000000000007ffff,
  0x000000000003ffff, 0x000000000003ffff,
  0x000000000001ffff, 0x000000000001ffff,
  0x000000000000ffff, 0x000000000000ffff,
  0x0000000000007fff, 0x0000000000007fff,
  0x0000000000003fff, 0x0000000000003fff,
  0x0000000000001fff, 0x0000000000001fff,
  0x0000000000000fff, 0x0000000000000fff,
  0x00000000000007ff, 0x00000000000007ff,
  0x00000000000003ff, 0x00000000000003ff,
  0x00000000000001ff, 0x00000000000001ff,
  0x00000000000000ff, 0x00000000000000ff,
  0x000000000000007f, 0x000000000000007f,
  0x000000000000003f, 0x000000000000003f,
  0x000000000000001f, 0x000000000000001f,
  0x000000000000000f, 0x000000000000000f,
  0x0000000000000007, 0x0000000000000007,
  0x0000000000000003, 0x0000000000000003,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x000000003fffffff, 0x1999999999999999,
  0x000000001fffffff, 0x0ccccccccccccccc,
  0x000000000fffffff, 0x0666666666666666,
  0x0000000007ffffff, 0x0333333333333333,
  0x0000000003ffffff, 0x0199999999999999,
  0x0000000001ffffff, 0x00cccccccccccccc,
  0x0000000000ffffff, 0x0066666666666666,
  0x00000000007fffff, 0x0033333333333333,
  0x00000000003fffff, 0x0019999999999999,
  0x00000000001fffff, 0x000ccccccccccccc,
  0x00000000000fffff, 0x0006666666666666,
  0x000000000007ffff, 0x0003333333333333,
  0x000000000003ffff, 0x0001999999999999,
  0x000000000001ffff, 0x0000cccccccccccc,
  0x000000000000ffff, 0x0000666666666666,
  0x0000000000007fff, 0x0000333333333333,
  0x0000000000003fff, 0x0000199999999999,
  0x0000000000001fff, 0x00000ccccccccccc,
  0x0000000000000fff, 0x0000066666666666,
  0x00000000000007ff, 0x0000033333333333,
  0x00000000000003ff, 0x0000019999999999,
  0x00000000000001ff, 0x000000cccccccccc,
  0x00000000000000ff, 0x0000006666666666,
  0x000000000000007f, 0x0000003333333333,
  0x000000000000003f, 0x0000001999999999,
  0x000000000000001f, 0x0000000ccccccccc,
  0x000000000000000f, 0x0000000666666666,
  0x0000000000000007, 0x0000000333333333,
  0x0000000000000003, 0x0000000199999999,
  0x0000000000000001, 0x00000000cccccccc,
  0x0000000000000000, 0x0000000066666666,
  0x0000000000000000, 0x0000000033333333,
  0x0000000000000000, 0x0000000019999999,
  0x0000000000000000, 0x000000000ccccccc,
  0x0000000000000000, 0x0000000006666666,
  0x0000000000000000, 0x0000000003333333,
  0x0000000000000000, 0x0000000001999999,
  0x0000000000000000, 0x0000000000cccccc,
  0x0000000000000000, 0x0000000000666666,
  0x0000000000000000, 0x0000000000333333,
  0x0000000000000000, 0x0000000000199999,
  0x0000000000000000, 0x00000000000ccccc,
  0x0000000000000000, 0x0000000000066666,
  0x0000000000000000, 0x0000000000033333,
  0x0000000000000000, 0x0000000000019999,
  0x0000000000000000, 0x000000000000cccc,
  0x0000000000000000, 0x0000000000006666,
  0x0000000000000000, 0x0000000000003333,
  0x0000000000000000, 0x0000000000001999,
  0x0000000000000000, 0x0000000000000ccc,
  0x0000000000000000, 0x0000000000000666,
  0x0000000000000000, 0x0000000000000333,
  0x0000000000000000, 0x0000000000000199,
  0x0000000000000000, 0x00000000000000cc,
  0x0000000000000000, 0x0000000000000066,
  0x0000000000000000, 0x0000000000000033,
  0x0000000000000000, 0x0000000000000019,
  0x0000000000000000, 0x000000000000000c,
  0x0000000000000000, 0x0000000000000006,
  0x0000000000000000, 0x0000000000000003,
  0x0000000000000000, 0x0000000000000001,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x1999999999999999, 0x2aaaaaaaaaaaaaaa,
  0x0ccccccccccccccc, 0x1555555555555555,
  0x0666666666666666, 0x0aaaaaaaaaaaaaaa,
  0x0333333333333333, 0x0555555555555555,
  0x0199999999999999, 0x02aaaaaaaaaaaaaa,
  0x00cccccccccccccc, 0x0155555555555555,
  0x0066666666666666, 0x00aaaaaaaaaaaaaa,
  0x0033333333333333, 0x0055555555555555,
  0x0019999999999999, 0x002aaaaaaaaaaaaa,
  0x000ccccccccccccc, 0x0015555555555555,
  0x0006666666666666, 0x000aaaaaaaaaaaaa,
  0x0003333333333333, 0x0005555555555555,
  0x0001999999999999, 0x0002aaaaaaaaaaaa,
  0x0000cccccccccccc, 0x0001555555555555,
  0x0000666666666666, 0x0000aaaaaaaaaaaa,
  0x0000333333333333, 0x0000555555555555,
  0x0000199999999999, 0x00002aaaaaaaaaaa,
  0x00000ccccccccccc, 0x0000155555555555,
  0x0000066666666666, 0x00000aaaaaaaaaaa,
  0x0000033333333333, 0x0000055555555555,
  0x0000019999999999, 0x000002aaaaaaaaaa,
  0x000000cccccccccc, 0x0000015555555555,
  0x0000006666666666, 0x000000aaaaaaaaaa,
  0x0000003333333333, 0x0000005555555555,
  0x0000001999999999, 0x0000002aaaaaaaaa,
  0x0000000ccccccccc, 0x0000001555555555,
  0x0000000666666666, 0x0000000aaaaaaaaa,
  0x0000000333333333, 0x0000000555555555,
  0x0000000199999999, 0x00000002aaaaaaaa,
  0x00000000cccccccc, 0x0000000155555555,
  0x0000000066666666, 0x00000000aaaaaaaa,
  0x0000000033333333, 0x0000000055555555,
  0x0000000019999999, 0x000000002aaaaaaa,
  0x000000000ccccccc, 0x0000000015555555,
  0x0000000006666666, 0x000000000aaaaaaa,
  0x0000000003333333, 0x0000000005555555,
  0x0000000001999999, 0x0000000002aaaaaa,
  0x0000000000cccccc, 0x0000000001555555,
  0x0000000000666666, 0x0000000000aaaaaa,
  0x0000000000333333, 0x0000000000555555,
  0x0000000000199999, 0x00000000002aaaaa,
  0x00000000000ccccc, 0x0000000000155555,
  0x0000000000066666, 0x00000000000aaaaa,
  0x0000000000033333, 0x0000000000055555,
  0x0000000000019999, 0x000000000002aaaa,
  0x000000000000cccc, 0x0000000000015555,
  0x0000000000006666, 0x000000000000aaaa,
  0x0000000000003333, 0x0000000000005555,
  0x0000000000001999, 0x0000000000002aaa,
  0x0000000000000ccc, 0x0000000000001555,
  0x0000000000000666, 0x0000000000000aaa,
  0x0000000000000333, 0x0000000000000555,
  0x0000000000000199, 0x00000000000002aa,
  0x00000000000000cc, 0x0000000000000155,
  0x0000000000000066, 0x00000000000000aa,
  0x0000000000000033, 0x0000000000000055,
  0x0000000000000019, 0x000000000000002a,
  0x000000000000000c, 0x0000000000000015,
  0x0000000000000006, 0x000000000000000a,
  0x0000000000000003, 0x0000000000000005,
  0x0000000000000001, 0x0000000000000002,
  0x0000000000000000, 0x0000000000000001,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x2aaaaaaaaaaaaaaa, 0x3ffffffffffffffe,
  0x1555555555555555, 0x1fffffffffffffff,
  0x0aaaaaaaaaaaaaaa, 0x0fffffffffffffff,
  0x0555555555555555, 0x07ffffffffffffff,
  0x02aaaaaaaaaaaaaa, 0x03ffffffffffffff,
  0x0155555555555555, 0x01ffffffffffffff,
  0x00aaaaaaaaaaaaaa, 0x00ffffffffffffff,
  0x0055555555555555, 0x007fffffffffffff,
  0x002aaaaaaaaaaaaa, 0x003fffffffffffff,
  0x0015555555555555, 0x001fffffffffffff,
  0x000aaaaaaaaaaaaa, 0x000fffffffffffff,
  0x0005555555555555, 0x0007ffffffffffff,
  0x0002aaaaaaaaaaaa, 0x0003ffffffffffff,
  0x0001555555555555, 0x0001ffffffffffff,
  0x0000aaaaaaaaaaaa, 0x0000ffffffffffff,
  0x0000555555555555, 0x00007fffffffffff,
  0x00002aaaaaaaaaaa, 0x00003fffffffffff,
  0x0000155555555555, 0x00001fffffffffff,
  0x00000aaaaaaaaaaa, 0x00000fffffffffff,
  0x0000055555555555, 0x000007ffffffffff,
  0x000002aaaaaaaaaa, 0x000003ffffffffff,
  0x0000015555555555, 0x000001ffffffffff,
  0x000000aaaaaaaaaa, 0x000000ffffffffff,
  0x0000005555555555, 0x0000007fffffffff,
  0x0000002aaaaaaaaa, 0x0000003fffffffff,
  0x0000001555555555, 0x0000001fffffffff,
  0x0000000aaaaaaaaa, 0x0000000fffffffff,
  0x0000000555555555, 0x00000007ffffffff,
  0x00000002aaaaaaaa, 0x00000003ffffffff,
  0x0000000155555555, 0x00000001ffffffff,
  0x00000000aaaaaaaa, 0x00000000ffffffff,
  0x0000000055555555, 0x000000007fffffff,
  0x000000002aaaaaaa, 0x000000003fffffff,
  0x0000000015555555, 0x000000001fffffff,
  0x000000000aaaaaaa, 0x000000000fffffff,
  0x0000000005555555, 0x0000000007ffffff,
  0x0000000002aaaaaa, 0x0000000003ffffff,
  0x0000000001555555, 0x0000000001ffffff,
  0x0000000000aaaaaa, 0x0000000000ffffff,
  0x0000000000555555, 0x00000000007fffff,
  0x00000000002aaaaa, 0x00000000003fffff,
  0x0000000000155555, 0x00000000001fffff,
  0x00000000000aaaaa, 0x00000000000fffff,
  0x0000000000055555, 0x000000000007ffff,
  0x000000000002aaaa, 0x000000000003ffff,
  0x0000000000015555, 0x000000000001ffff,
  0x000000000000aaaa, 0x000000000000ffff,
  0x0000000000005555, 0x0000000000007fff,
  0x0000000000002aaa, 0x0000000000003fff,
  0x0000000000001555, 0x0000000000001fff,
  0x0000000000000aaa, 0x0000000000000fff,
  0x0000000000000555, 0x00000000000007ff,
  0x00000000000002aa, 0x00000000000003ff,
  0x0000000000000155, 0x00000000000001ff,
  0x00000000000000aa, 0x00000000000000ff,
  0x0000000000000055, 0x000000000000007f,
  0x000000000000002a, 0x000000000000003f,
  0x0000000000000015, 0x000000000000001f,
  0x000000000000000a, 0x000000000000000f,
  0x0000000000000005, 0x0000000000000007,
  0x0000000000000002, 0x0000000000000003,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x3ffffffffffffffe, 0x3fffffffffffffff,
  0x1fffffffffffffff, 0x1fffffffffffffff,
  0x0fffffffffffffff, 0x0fffffffffffffff,
  0x07ffffffffffffff, 0x07ffffffffffffff,
  0x03ffffffffffffff, 0x03ffffffffffffff,
  0x01ffffffffffffff, 0x01ffffffffffffff,
  0x00ffffffffffffff, 0x00ffffffffffffff,
  0x007fffffffffffff, 0x007fffffffffffff,
  0x003fffffffffffff, 0x003fffffffffffff,
  0x001fffffffffffff, 0x001fffffffffffff,
  0x000fffffffffffff, 0x000fffffffffffff,
  0x0007ffffffffffff, 0x0007ffffffffffff,
  0x0003ffffffffffff, 0x0003ffffffffffff,
  0x0001ffffffffffff, 0x0001ffffffffffff,
  0x0000ffffffffffff, 0x0000ffffffffffff,
  0x00007fffffffffff, 0x00007fffffffffff,
  0x00003fffffffffff, 0x00003fffffffffff,
  0x00001fffffffffff, 0x00001fffffffffff,
  0x00000fffffffffff, 0x00000fffffffffff,
  0x000007ffffffffff, 0x000007ffffffffff,
  0x000003ffffffffff, 0x000003ffffffffff,
  0x000001ffffffffff, 0x000001ffffffffff,
  0x000000ffffffffff, 0x000000ffffffffff,
  0x0000007fffffffff, 0x0000007fffffffff,
  0x0000003fffffffff, 0x0000003fffffffff,
  0x0000001fffffffff, 0x0000001fffffffff,
  0x0000000fffffffff, 0x0000000fffffffff,
  0x00000007ffffffff, 0x00000007ffffffff,
  0x00000003ffffffff, 0x00000003ffffffff,
  0x00000001ffffffff, 0x00000001ffffffff,
  0x00000000ffffffff, 0x00000000ffffffff,
  0x000000007fffffff, 0x000000007fffffff,
  0x000000003fffffff, 0x000000003fffffff,
  0x000000001fffffff, 0x000000001fffffff,
  0x000000000fffffff, 0x000000000fffffff,
  0x0000000007ffffff, 0x0000000007ffffff,
  0x0000000003ffffff, 0x0000000003ffffff,
  0x0000000001ffffff, 0x0000000001ffffff,
  0x0000000000ffffff, 0x0000000000ffffff,
  0x00000000007fffff, 0x00000000007fffff,
  0x00000000003fffff, 0x00000000003fffff,
  0x00000000001fffff, 0x00000000001fffff,
  0x00000000000fffff, 0x00000000000fffff,
  0x000000000007ffff, 0x000000000007ffff,
  0x000000000003ffff, 0x000000000003ffff,
  0x000000000001ffff, 0x000000000001ffff,
  0x000000000000ffff, 0x000000000000ffff,
  0x0000000000007fff, 0x0000000000007fff,
  0x0000000000003fff, 0x0000000000003fff,
  0x0000000000001fff, 0x0000000000001fff,
  0x0000000000000fff, 0x0000000000000fff,
  0x00000000000007ff, 0x00000000000007ff,
  0x00000000000003ff, 0x00000000000003ff,
  0x00000000000001ff, 0x00000000000001ff,
  0x00000000000000ff, 0x00000000000000ff,
  0x000000000000007f, 0x000000000000007f,
  0x000000000000003f, 0x000000000000003f,
  0x000000000000001f, 0x000000000000001f,
  0x000000000000000f, 0x000000000000000f,
  0x0000000000000007, 0x0000000000000007,
  0x0000000000000003, 0x0000000000000003,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x3fffffffffffffff, 0x3fffffffffffffff,
  0x1fffffffffffffff, 0x1fffffffffffffff,
  0x0fffffffffffffff, 0x0fffffffffffffff,
  0x07ffffffffffffff, 0x07ffffffffffffff,
  0x03ffffffffffffff, 0x03ffffffffffffff,
  0x01ffffffffffffff, 0x01ffffffffffffff,
  0x00ffffffffffffff, 0x00ffffffffffffff,
  0x007fffffffffffff, 0x007fffffffffffff,
  0x003fffffffffffff, 0x003fffffffffffff,
  0x001fffffffffffff, 0x001fffffffffffff,
  0x000fffffffffffff, 0x000fffffffffffff,
  0x0007ffffffffffff, 0x0007ffffffffffff,
  0x0003ffffffffffff, 0x0003ffffffffffff,
  0x0001ffffffffffff, 0x0001ffffffffffff,
  0x0000ffffffffffff, 0x0000ffffffffffff,
  0x00007fffffffffff, 0x00007fffffffffff,
  0x00003fffffffffff, 0x00003fffffffffff,
  0x00001fffffffffff, 0x00001fffffffffff,
  0x00000fffffffffff, 0x00000fffffffffff,
  0x000007ffffffffff, 0x000007ffffffffff,
  0x000003ffffffffff, 0x000003ffffffffff,
  0x000001ffffffffff, 0x000001ffffffffff,
  0x000000ffffffffff, 0x000000ffffffffff,
  0x0000007fffffffff, 0x0000007fffffffff,
  0x0000003fffffffff, 0x0000003fffffffff,
  0x0000001fffffffff, 0x0000001fffffffff,
  0x0000000fffffffff, 0x0000000fffffffff,
  0x00000007ffffffff, 0x00000007ffffffff,
  0x00000003ffffffff, 0x00000003ffffffff,
  0x00000001ffffffff, 0x00000001ffffffff,
  0x00000000ffffffff, 0x00000000ffffffff,
  0x000000007fffffff, 0x000000007fffffff,
  0x000000003fffffff, 0x000000003fffffff,
  0x000000001fffffff, 0x000000001fffffff,
  0x000000000fffffff, 0x000000000fffffff,
  0x0000000007ffffff, 0x0000000007ffffff,
  0x0000000003ffffff, 0x0000000003ffffff,
  0x0000000001ffffff, 0x0000000001ffffff,
  0x0000000000ffffff, 0x0000000000ffffff,
  0x00000000007fffff, 0x00000000007fffff,
  0x00000000003fffff, 0x00000000003fffff,
  0x00000000001fffff, 0x00000000001fffff,
  0x00000000000fffff, 0x00000000000fffff,
  0x000000000007ffff, 0x000000000007ffff,
  0x000000000003ffff, 0x000000000003ffff,
  0x000000000001ffff, 0x000000000001ffff,
  0x000000000000ffff, 0x000000000000ffff,
  0x0000000000007fff, 0x0000000000007fff,
  0x0000000000003fff, 0x0000000000003fff,
  0x0000000000001fff, 0x0000000000001fff,
  0x0000000000000fff, 0x0000000000000fff,
  0x00000000000007ff, 0x00000000000007ff,
  0x00000000000003ff, 0x00000000000003ff,
  0x00000000000001ff, 0x00000000000001ff,
  0x00000000000000ff, 0x00000000000000ff,
  0x000000000000007f, 0x000000000000007f,
  0x000000000000003f, 0x000000000000003f,
  0x000000000000001f, 0x000000000000001f,
  0x000000000000000f, 0x000000000000000f,
  0x0000000000000007, 0x0000000000000007,
  0x0000000000000003, 0x0000000000000003,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x3fffffffffffffff, 0xc000000000000000,
  0x1fffffffffffffff, 0xe000000000000000,
  0x0fffffffffffffff, 0xf000000000000000,
  0x07ffffffffffffff, 0xf800000000000000,
  0x03ffffffffffffff, 0xfc00000000000000,
  0x01ffffffffffffff, 0xfe00000000000000,
  0x00ffffffffffffff, 0xff00000000000000,
  0x007fffffffffffff, 0xff80000000000000,
  0x003fffffffffffff, 0xffc0000000000000,
  0x001fffffffffffff, 0xffe0000000000000,
  0x000fffffffffffff, 0xfff0000000000000,
  0x0007ffffffffffff, 0xfff8000000000000,
  0x0003ffffffffffff, 0xfffc000000000000,
  0x0001ffffffffffff, 0xfffe000000000000,
  0x0000ffffffffffff, 0xffff000000000000,
  0x00007fffffffffff, 0xffff800000000000,
  0x00003fffffffffff, 0xffffc00000000000,
  0x00001fffffffffff, 0xffffe00000000000,
  0x00000fffffffffff, 0xfffff00000000000,
  0x000007ffffffffff, 0xfffff80000000000,
  0x000003ffffffffff, 0xfffffc0000000000,
  0x000001ffffffffff, 0xfffffe0000000000,
  0x000000ffffffffff, 0xffffff0000000000,
  0x0000007fffffffff, 0xffffff8000000000,
  0x0000003fffffffff, 0xffffffc000000000,
  0x0000001fffffffff, 0xffffffe000000000,
  0x0000000fffffffff, 0xfffffff000000000,
  0x00000007ffffffff, 0xfffffff800000000,
  0x00000003ffffffff, 0xfffffffc00000000,
  0x00000001ffffffff, 0xfffffffe00000000,
  0x00000000ffffffff, 0xffffffff00000000,
  0x000000007fffffff, 0xffffffff80000000,
  0x000000003fffffff, 0xffffffffc0000000,
  0x000000001fffffff, 0xffffffffe0000000,
  0x000000000fffffff, 0xfffffffff0000000,
  0x0000000007ffffff, 0xfffffffff8000000,
  0x0000000003ffffff, 0xfffffffffc000000,
  0x0000000001ffffff, 0xfffffffffe000000,
  0x0000000000ffffff, 0xffffffffff000000,
  0x00000000007fffff, 0xffffffffff800000,
  0x00000000003fffff, 0xffffffffffc00000,
  0x00000000001fffff, 0xffffffffffe00000,
  0x00000000000fffff, 0xfffffffffff00000,
  0x000000000007ffff, 0xfffffffffff80000,
  0x000000000003ffff, 0xfffffffffffc0000,
  0x000000000001ffff, 0xfffffffffffe0000,
  0x000000000000ffff, 0xffffffffffff0000,
  0x0000000000007fff, 0xffffffffffff8000,
  0x0000000000003fff, 0xffffffffffffc000,
  0x0000000000001fff, 0xffffffffffffe000,
  0x0000000000000fff, 0xfffffffffffff000,
  0x00000000000007ff, 0xfffffffffffff800,
  0x00000000000003ff, 0xfffffffffffffc00,
  0x00000000000001ff, 0xfffffffffffffe00,
  0x00000000000000ff, 0xffffffffffffff00,
  0x000000000000007f, 0xffffffffffffff80,
  0x000000000000003f, 0xffffffffffffffc0,
  0x000000000000001f, 0xffffffffffffffe0,
  0x000000000000000f, 0xfffffffffffffff0,
  0x0000000000000007, 0xfffffffffffffff8,
  0x0000000000000003, 0xfffffffffffffffc,
  0x0000000000000001, 0xfffffffffffffffe,
  0x0000000000000000, 0xffffffffffffffff,
  0x0000000000000000, 0xffffffffffffffff,
  0xc000000000000000, 0xc000000000000000,
  0xe000000000000000, 0xe000000000000000,
  0xf000000000000000, 0xf000000000000000,
  0xf800000000000000, 0xf800000000000000,
  0xfc00000000000000, 0xfc00000000000000,
  0xfe00000000000000, 0xfe00000000000000,
  0xff00000000000000, 0xff00000000000000,
  0xff80000000000000, 0xff80000000000000,
  0xffc0000000000000, 0xffc0000000000000,
  0xffe0000000000000, 0xffe0000000000000,
  0xfff0000000000000, 0xfff0000000000000,
  0xfff8000000000000, 0xfff8000000000000,
  0xfffc000000000000, 0xfffc000000000000,
  0xfffe000000000000, 0xfffe000000000000,
  0xffff000000000000, 0xffff000000000000,
  0xffff800000000000, 0xffff800000000000,
  0xffffc00000000000, 0xffffc00000000000,
  0xffffe00000000000, 0xffffe00000000000,
  0xfffff00000000000, 0xfffff00000000000,
  0xfffff80000000000, 0xfffff80000000000,
  0xfffffc0000000000, 0xfffffc0000000000,
  0xfffffe0000000000, 0xfffffe0000000000,
  0xffffff0000000000, 0xffffff0000000000,
  0xffffff8000000000, 0xffffff8000000000,
  0xffffffc000000000, 0xffffffc000000000,
  0xffffffe000000000, 0xffffffe000000000,
  0xfffffff000000000, 0xfffffff000000000,
  0xfffffff800000000, 0xfffffff800000000,
  0xfffffffc00000000, 0xfffffffc00000000,
  0xfffffffe00000000, 0xfffffffe00000000,
  0xffffffff00000000, 0xffffffff00000000,
  0xffffffff80000000, 0xffffffff80000000,
  0xffffffffc0000000, 0xffffffffc0000000,
  0xffffffffe0000000, 0xffffffffe0000000,
  0xfffffffff0000000, 0xfffffffff0000000,
  0xfffffffff8000000, 0xfffffffff8000000,
  0xfffffffffc000000, 0xfffffffffc000000,
  0xfffffffffe000000, 0xfffffffffe000000,
  0xffffffffff000000, 0xffffffffff000000,
  0xffffffffff800000, 0xffffffffff800000,
  0xffffffffffc00000, 0xffffffffffc00000,
  0xffffffffffe00000, 0xffffffffffe00000,
  0xfffffffffff00000, 0xfffffffffff00000,
  0xfffffffffff80000, 0xfffffffffff80000,
  0xfffffffffffc0000, 0xfffffffffffc0000,
  0xfffffffffffe0000, 0xfffffffffffe0000,
  0xffffffffffff0000, 0xffffffffffff0000,
  0xffffffffffff8000, 0xffffffffffff8000,
  0xffffffffffffc000, 0xffffffffffffc000,
  0xffffffffffffe000, 0xffffffffffffe000,
  0xfffffffffffff000, 0xfffffffffffff000,
  0xfffffffffffff800, 0xfffffffffffff800,
  0xfffffffffffffc00, 0xfffffffffffffc00,
  0xfffffffffffffe00, 0xfffffffffffffe00,
  0xffffffffffffff00, 0xffffffffffffff00,
  0xffffffffffffff80, 0xffffffffffffff80,
  0xffffffffffffffc0, 0xffffffffffffffc0,
  0xffffffffffffffe0, 0xffffffffffffffe0,
  0xfffffffffffffff0, 0xfffffffffffffff0,
  0xfffffffffffffff8, 0xfffffffffffffff8,
  0xfffffffffffffffc, 0xfffffffffffffffc,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xc000000000000000, 0xc000000000000001,
  0xe000000000000000, 0xe000000000000000,
  0xf000000000000000, 0xf000000000000000,
  0xf800000000000000, 0xf800000000000000,
  0xfc00000000000000, 0xfc00000000000000,
  0xfe00000000000000, 0xfe00000000000000,
  0xff00000000000000, 0xff00000000000000,
  0xff80000000000000, 0xff80000000000000,
  0xffc0000000000000, 0xffc0000000000000,
  0xffe0000000000000, 0xffe0000000000000,
  0xfff0000000000000, 0xfff0000000000000,
  0xfff8000000000000, 0xfff8000000000000,
  0xfffc000000000000, 0xfffc000000000000,
  0xfffe000000000000, 0xfffe000000000000,
  0xffff000000000000, 0xffff000000000000,
  0xffff800000000000, 0xffff800000000000,
  0xffffc00000000000, 0xffffc00000000000,
  0xffffe00000000000, 0xffffe00000000000,
  0xfffff00000000000, 0xfffff00000000000,
  0xfffff80000000000, 0xfffff80000000000,
  0xfffffc0000000000, 0xfffffc0000000000,
  0xfffffe0000000000, 0xfffffe0000000000,
  0xffffff0000000000, 0xffffff0000000000,
  0xffffff8000000000, 0xffffff8000000000,
  0xffffffc000000000, 0xffffffc000000000,
  0xffffffe000000000, 0xffffffe000000000,
  0xfffffff000000000, 0xfffffff000000000,
  0xfffffff800000000, 0xfffffff800000000,
  0xfffffffc00000000, 0xfffffffc00000000,
  0xfffffffe00000000, 0xfffffffe00000000,
  0xffffffff00000000, 0xffffffff00000000,
  0xffffffff80000000, 0xffffffff80000000,
  0xffffffffc0000000, 0xffffffffc0000000,
  0xffffffffe0000000, 0xffffffffe0000000,
  0xfffffffff0000000, 0xfffffffff0000000,
  0xfffffffff8000000, 0xfffffffff8000000,
  0xfffffffffc000000, 0xfffffffffc000000,
  0xfffffffffe000000, 0xfffffffffe000000,
  0xffffffffff000000, 0xffffffffff000000,
  0xffffffffff800000, 0xffffffffff800000,
  0xffffffffffc00000, 0xffffffffffc00000,
  0xffffffffffe00000, 0xffffffffffe00000,
  0xfffffffffff00000, 0xfffffffffff00000,
  0xfffffffffff80000, 0xfffffffffff80000,
  0xfffffffffffc0000, 0xfffffffffffc0000,
  0xfffffffffffe0000, 0xfffffffffffe0000,
  0xffffffffffff0000, 0xffffffffffff0000,
  0xffffffffffff8000, 0xffffffffffff8000,
  0xffffffffffffc000, 0xffffffffffffc000,
  0xffffffffffffe000, 0xffffffffffffe000,
  0xfffffffffffff000, 0xfffffffffffff000,
  0xfffffffffffff800, 0xfffffffffffff800,
  0xfffffffffffffc00, 0xfffffffffffffc00,
  0xfffffffffffffe00, 0xfffffffffffffe00,
  0xffffffffffffff00, 0xffffffffffffff00,
  0xffffffffffffff80, 0xffffffffffffff80,
  0xffffffffffffffc0, 0xffffffffffffffc0,
  0xffffffffffffffe0, 0xffffffffffffffe0,
  0xfffffffffffffff0, 0xfffffffffffffff0,
  0xfffffffffffffff8, 0xfffffffffffffff8,
  0xfffffffffffffffc, 0xfffffffffffffffc,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xc000000000000001, 0xc000000000000001,
  0xe000000000000000, 0xe000000000000000,
  0xf000000000000000, 0xf000000000000000,
  0xf800000000000000, 0xf800000000000000,
  0xfc00000000000000, 0xfc00000000000000,
  0xfe00000000000000, 0xfe00000000000000,
  0xff00000000000000, 0xff00000000000000,
  0xff80000000000000, 0xff80000000000000,
  0xffc0000000000000, 0xffc0000000000000,
  0xffe0000000000000, 0xffe0000000000000,
  0xfff0000000000000, 0xfff0000000000000,
  0xfff8000000000000, 0xfff8000000000000,
  0xfffc000000000000, 0xfffc000000000000,
  0xfffe000000000000, 0xfffe000000000000,
  0xffff000000000000, 0xffff000000000000,
  0xffff800000000000, 0xffff800000000000,
  0xffffc00000000000, 0xffffc00000000000,
  0xffffe00000000000, 0xffffe00000000000,
  0xfffff00000000000, 0xfffff00000000000,
  0xfffff80000000000, 0xfffff80000000000,
  0xfffffc0000000000, 0xfffffc0000000000,
  0xfffffe0000000000, 0xfffffe0000000000,
  0xffffff0000000000, 0xffffff0000000000,
  0xffffff8000000000, 0xffffff8000000000,
  0xffffffc000000000, 0xffffffc000000000,
  0xffffffe000000000, 0xffffffe000000000,
  0xfffffff000000000, 0xfffffff000000000,
  0xfffffff800000000, 0xfffffff800000000,
  0xfffffffc00000000, 0xfffffffc00000000,
  0xfffffffe00000000, 0xfffffffe00000000,
  0xffffffff00000000, 0xffffffff00000000,
  0xffffffff80000000, 0xffffffff80000000,
  0xffffffffc0000000, 0xffffffffc0000000,
  0xffffffffe0000000, 0xffffffffe0000000,
  0xfffffffff0000000, 0xfffffffff0000000,
  0xfffffffff8000000, 0xfffffffff8000000,
  0xfffffffffc000000, 0xfffffffffc000000,
  0xfffffffffe000000, 0xfffffffffe000000,
  0xffffffffff000000, 0xffffffffff000000,
  0xffffffffff800000, 0xffffffffff800000,
  0xffffffffffc00000, 0xffffffffffc00000,
  0xffffffffffe00000, 0xffffffffffe00000,
  0xfffffffffff00000, 0xfffffffffff00000,
  0xfffffffffff80000, 0xfffffffffff80000,
  0xfffffffffffc0000, 0xfffffffffffc0000,
  0xfffffffffffe0000, 0xfffffffffffe0000,
  0xffffffffffff0000, 0xffffffffffff0000,
  0xffffffffffff8000, 0xffffffffffff8000,
  0xffffffffffffc000, 0xffffffffffffc000,
  0xffffffffffffe000, 0xffffffffffffe000,
  0xfffffffffffff000, 0xfffffffffffff000,
  0xfffffffffffff800, 0xfffffffffffff800,
  0xfffffffffffffc00, 0xfffffffffffffc00,
  0xfffffffffffffe00, 0xfffffffffffffe00,
  0xffffffffffffff00, 0xffffffffffffff00,
  0xffffffffffffff80, 0xffffffffffffff80,
  0xffffffffffffffc0, 0xffffffffffffffc0,
  0xffffffffffffffe0, 0xffffffffffffffe0,
  0xfffffffffffffff0, 0xfffffffffffffff0,
  0xfffffffffffffff8, 0xfffffffffffffff8,
  0xfffffffffffffffc, 0xfffffffffffffffc,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xc000000000000001, 0xd555555555555555,
  0xe000000000000000, 0xeaaaaaaaaaaaaaaa,
  0xf000000000000000, 0xf555555555555555,
  0xf800000000000000, 0xfaaaaaaaaaaaaaaa,
  0xfc00000000000000, 0xfd55555555555555,
  0xfe00000000000000, 0xfeaaaaaaaaaaaaaa,
  0xff00000000000000, 0xff55555555555555,
  0xff80000000000000, 0xffaaaaaaaaaaaaaa,
  0xffc0000000000000, 0xffd5555555555555,
  0xffe0000000000000, 0xffeaaaaaaaaaaaaa,
  0xfff0000000000000, 0xfff5555555555555,
  0xfff8000000000000, 0xfffaaaaaaaaaaaaa,
  0xfffc000000000000, 0xfffd555555555555,
  0xfffe000000000000, 0xfffeaaaaaaaaaaaa,
  0xffff000000000000, 0xffff555555555555,
  0xffff800000000000, 0xffffaaaaaaaaaaaa,
  0xffffc00000000000, 0xffffd55555555555,
  0xffffe00000000000, 0xffffeaaaaaaaaaaa,
  0xfffff00000000000, 0xfffff55555555555,
  0xfffff80000000000, 0xfffffaaaaaaaaaaa,
  0xfffffc0000000000, 0xfffffd5555555555,
  0xfffffe0000000000, 0xfffffeaaaaaaaaaa,
  0xffffff0000000000, 0xffffff5555555555,
  0xffffff8000000000, 0xffffffaaaaaaaaaa,
  0xffffffc000000000, 0xffffffd555555555,
  0xffffffe000000000, 0xffffffeaaaaaaaaa,
  0xfffffff000000000, 0xfffffff555555555,
  0xfffffff800000000, 0xfffffffaaaaaaaaa,
  0xfffffffc00000000, 0xfffffffd55555555,
  0xfffffffe00000000, 0xfffffffeaaaaaaaa,
  0xffffffff00000000, 0xffffffff55555555,
  0xffffffff80000000, 0xffffffffaaaaaaaa,
  0xffffffffc0000000, 0xffffffffd5555555,
  0xffffffffe0000000, 0xffffffffeaaaaaaa,
  0xfffffffff0000000, 0xfffffffff5555555,
  0xfffffffff8000000, 0xfffffffffaaaaaaa,
  0xfffffffffc000000, 0xfffffffffd555555,
  0xfffffffffe000000, 0xfffffffffeaaaaaa,
  0xffffffffff000000, 0xffffffffff555555,
  0xffffffffff800000, 0xffffffffffaaaaaa,
  0xffffffffffc00000, 0xffffffffffd55555,
  0xffffffffffe00000, 0xffffffffffeaaaaa,
  0xfffffffffff00000, 0xfffffffffff55555,
  0xfffffffffff80000, 0xfffffffffffaaaaa,
  0xfffffffffffc0000, 0xfffffffffffd5555,
  0xfffffffffffe0000, 0xfffffffffffeaaaa,
  0xffffffffffff0000, 0xffffffffffff5555,
  0xffffffffffff8000, 0xffffffffffffaaaa,
  0xffffffffffffc000, 0xffffffffffffd555,
  0xffffffffffffe000, 0xffffffffffffeaaa,
  0xfffffffffffff000, 0xfffffffffffff555,
  0xfffffffffffff800, 0xfffffffffffffaaa,
  0xfffffffffffffc00, 0xfffffffffffffd55,
  0xfffffffffffffe00, 0xfffffffffffffeaa,
  0xffffffffffffff00, 0xffffffffffffff55,
  0xffffffffffffff80, 0xffffffffffffffaa,
  0xffffffffffffffc0, 0xffffffffffffffd5,
  0xffffffffffffffe0, 0xffffffffffffffea,
  0xfffffffffffffff0, 0xfffffffffffffff5,
  0xfffffffffffffff8, 0xfffffffffffffffa,
  0xfffffffffffffffc, 0xfffffffffffffffd,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xd555555555555555, 0xe666666666666666,
  0xeaaaaaaaaaaaaaaa, 0xf333333333333333,
  0xf555555555555555, 0xf999999999999999,
  0xfaaaaaaaaaaaaaaa, 0xfccccccccccccccc,
  0xfd55555555555555, 0xfe66666666666666,
  0xfeaaaaaaaaaaaaaa, 0xff33333333333333,
  0xff55555555555555, 0xff99999999999999,
  0xffaaaaaaaaaaaaaa, 0xffcccccccccccccc,
  0xffd5555555555555, 0xffe6666666666666,
  0xffeaaaaaaaaaaaaa, 0xfff3333333333333,
  0xfff5555555555555, 0xfff9999999999999,
  0xfffaaaaaaaaaaaaa, 0xfffccccccccccccc,
  0xfffd555555555555, 0xfffe666666666666,
  0xfffeaaaaaaaaaaaa, 0xffff333333333333,
  0xffff555555555555, 0xffff999999999999,
  0xffffaaaaaaaaaaaa, 0xffffcccccccccccc,
  0xffffd55555555555, 0xffffe66666666666,
  0xffffeaaaaaaaaaaa, 0xfffff33333333333,
  0xfffff55555555555, 0xfffff99999999999,
  0xfffffaaaaaaaaaaa, 0xfffffccccccccccc,
  0xfffffd5555555555, 0xfffffe6666666666,
  0xfffffeaaaaaaaaaa, 0xffffff3333333333,
  0xffffff5555555555, 0xffffff9999999999,
  0xffffffaaaaaaaaaa, 0xffffffcccccccccc,
  0xffffffd555555555, 0xffffffe666666666,
  0xffffffeaaaaaaaaa, 0xfffffff333333333,
  0xfffffff555555555, 0xfffffff999999999,
  0xfffffffaaaaaaaaa, 0xfffffffccccccccc,
  0xfffffffd55555555, 0xfffffffe66666666,
  0xfffffffeaaaaaaaa, 0xffffffff33333333,
  0xffffffff55555555, 0xffffffff99999999,
  0xffffffffaaaaaaaa, 0xffffffffcccccccc,
  0xffffffffd5555555, 0xffffffffe6666666,
  0xffffffffeaaaaaaa, 0xfffffffff3333333,
  0xfffffffff5555555, 0xfffffffff9999999,
  0xfffffffffaaaaaaa, 0xfffffffffccccccc,
  0xfffffffffd555555, 0xfffffffffe666666,
  0xfffffffffeaaaaaa, 0xffffffffff333333,
  0xffffffffff555555, 0xffffffffff999999,
  0xffffffffffaaaaaa, 0xffffffffffcccccc,
  0xffffffffffd55555, 0xffffffffffe66666,
  0xffffffffffeaaaaa, 0xfffffffffff33333,
  0xfffffffffff55555, 0xfffffffffff99999,
  0xfffffffffffaaaaa, 0xfffffffffffccccc,
  0xfffffffffffd5555, 0xfffffffffffe6666,
  0xfffffffffffeaaaa, 0xffffffffffff3333,
  0xffffffffffff5555, 0xffffffffffff9999,
  0xffffffffffffaaaa, 0xffffffffffffcccc,
  0xffffffffffffd555, 0xffffffffffffe666,
  0xffffffffffffeaaa, 0xfffffffffffff333,
  0xfffffffffffff555, 0xfffffffffffff999,
  0xfffffffffffffaaa, 0xfffffffffffffccc,
  0xfffffffffffffd55, 0xfffffffffffffe66,
  0xfffffffffffffeaa, 0xffffffffffffff33,
  0xffffffffffffff55, 0xffffffffffffff99,
  0xffffffffffffffaa, 0xffffffffffffffcc,
  0xffffffffffffffd5, 0xffffffffffffffe6,
  0xffffffffffffffea, 0xfffffffffffffff3,
  0xfffffffffffffff5, 0xfffffffffffffff9,
  0xfffffffffffffffa, 0xfffffffffffffffc,
  0xfffffffffffffffd, 0xfffffffffffffffe,
  0xfffffffffffffffe, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xe666666666666666, 0xffffffffc0000000,
  0xf333333333333333, 0xffffffffe0000000,
  0xf999999999999999, 0xfffffffff0000000,
  0xfccccccccccccccc, 0xfffffffff8000000,
  0xfe66666666666666, 0xfffffffffc000000,
  0xff33333333333333, 0xfffffffffe000000,
  0xff99999999999999, 0xffffffffff000000,
  0xffcccccccccccccc, 0xffffffffff800000,
  0xffe6666666666666, 0xffffffffffc00000,
  0xfff3333333333333, 0xffffffffffe00000,
  0xfff9999999999999, 0xfffffffffff00000,
  0xfffccccccccccccc, 0xfffffffffff80000,
  0xfffe666666666666, 0xfffffffffffc0000,
  0xffff333333333333, 0xfffffffffffe0000,
  0xffff999999999999, 0xffffffffffff0000,
  0xffffcccccccccccc, 0xffffffffffff8000,
  0xffffe66666666666, 0xffffffffffffc000,
  0xfffff33333333333, 0xffffffffffffe000,
  0xfffff99999999999, 0xfffffffffffff000,
  0xfffffccccccccccc, 0xfffffffffffff800,
  0xfffffe6666666666, 0xfffffffffffffc00,
  0xffffff3333333333, 0xfffffffffffffe00,
  0xffffff9999999999, 0xffffffffffffff00,
  0xffffffcccccccccc, 0xffffffffffffff80,
  0xffffffe666666666, 0xffffffffffffffc0,
  0xfffffff333333333, 0xffffffffffffffe0,
  0xfffffff999999999, 0xfffffffffffffff0,
  0xfffffffccccccccc, 0xfffffffffffffff8,
  0xfffffffe66666666, 0xfffffffffffffffc,
  0xffffffff33333333, 0xfffffffffffffffe,
  0xffffffff99999999, 0xffffffffffffffff,
  0xffffffffcccccccc, 0xffffffffffffffff,
  0xffffffffe6666666, 0xffffffffffffffff,
  0xfffffffff3333333, 0xffffffffffffffff,
  0xfffffffff9999999, 0xffffffffffffffff,
  0xfffffffffccccccc, 0xffffffffffffffff,
  0xfffffffffe666666, 0xffffffffffffffff,
  0xffffffffff333333, 0xffffffffffffffff,
  0xffffffffff999999, 0xffffffffffffffff,
  0xffffffffffcccccc, 0xffffffffffffffff,
  0xffffffffffe66666, 0xffffffffffffffff,
  0xfffffffffff33333, 0xffffffffffffffff,
  0xfffffffffff99999, 0xffffffffffffffff,
  0xfffffffffffccccc, 0xffffffffffffffff,
  0xfffffffffffe6666, 0xffffffffffffffff,
  0xffffffffffff3333, 0xffffffffffffffff,
  0xffffffffffff9999, 0xffffffffffffffff,
  0xffffffffffffcccc, 0xffffffffffffffff,
  0xffffffffffffe666, 0xffffffffffffffff,
  0xfffffffffffff333, 0xffffffffffffffff,
  0xfffffffffffff999, 0xffffffffffffffff,
  0xfffffffffffffccc, 0xffffffffffffffff,
  0xfffffffffffffe66, 0xffffffffffffffff,
  0xffffffffffffff33, 0xffffffffffffffff,
  0xffffffffffffff99, 0xffffffffffffffff,
  0xffffffffffffffcc, 0xffffffffffffffff,
  0xffffffffffffffe6, 0xffffffffffffffff,
  0xfffffffffffffff3, 0xffffffffffffffff,
  0xfffffffffffffff9, 0xffffffffffffffff,
  0xfffffffffffffffc, 0xffffffffffffffff,
  0xfffffffffffffffe, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffc0000000, 0xffffffffc0000000,
  0xffffffffe0000000, 0xffffffffe0000000,
  0xfffffffff0000000, 0xfffffffff0000000,
  0xfffffffff8000000, 0xfffffffff8000000,
  0xfffffffffc000000, 0xfffffffffc000000,
  0xfffffffffe000000, 0xfffffffffe000000,
  0xffffffffff000000, 0xffffffffff000000,
  0xffffffffff800000, 0xffffffffff800000,
  0xffffffffffc00000, 0xffffffffffc00000,
  0xffffffffffe00000, 0xffffffffffe00000,
  0xfffffffffff00000, 0xfffffffffff00000,
  0xfffffffffff80000, 0xfffffffffff80000,
  0xfffffffffffc0000, 0xfffffffffffc0000,
  0xfffffffffffe0000, 0xfffffffffffe0000,
  0xffffffffffff0000, 0xffffffffffff0000,
  0xffffffffffff8000, 0xffffffffffff8000,
  0xffffffffffffc000, 0xffffffffffffc000,
  0xffffffffffffe000, 0xffffffffffffe000,
  0xfffffffffffff000, 0xfffffffffffff000,
  0xfffffffffffff800, 0xfffffffffffff800,
  0xfffffffffffffc00, 0xfffffffffffffc00,
  0xfffffffffffffe00, 0xfffffffffffffe00,
  0xffffffffffffff00, 0xffffffffffffff00,
  0xffffffffffffff80, 0xffffffffffffff80,
  0xffffffffffffffc0, 0xffffffffffffffc0,
  0xffffffffffffffe0, 0xffffffffffffffe0,
  0xfffffffffffffff0, 0xfffffffffffffff0,
  0xfffffffffffffff8, 0xfffffffffffffff8,
  0xfffffffffffffffc, 0xfffffffffffffffc,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffc0000000, 0xffffffffc0000001,
  0xffffffffe0000000, 0xffffffffe0000000,
  0xfffffffff0000000, 0xfffffffff0000000,
  0xfffffffff8000000, 0xfffffffff8000000,
  0xfffffffffc000000, 0xfffffffffc000000,
  0xfffffffffe000000, 0xfffffffffe000000,
  0xffffffffff000000, 0xffffffffff000000,
  0xffffffffff800000, 0xffffffffff800000,
  0xffffffffffc00000, 0xffffffffffc00000,
  0xffffffffffe00000, 0xffffffffffe00000,
  0xfffffffffff00000, 0xfffffffffff00000,
  0xfffffffffff80000, 0xfffffffffff80000,
  0xfffffffffffc0000, 0xfffffffffffc0000,
  0xfffffffffffe0000, 0xfffffffffffe0000,
  0xffffffffffff0000, 0xffffffffffff0000,
  0xffffffffffff8000, 0xffffffffffff8000,
  0xffffffffffffc000, 0xffffffffffffc000,
  0xffffffffffffe000, 0xffffffffffffe000,
  0xfffffffffffff000, 0xfffffffffffff000,
  0xfffffffffffff800, 0xfffffffffffff800,
  0xfffffffffffffc00, 0xfffffffffffffc00,
  0xfffffffffffffe00, 0xfffffffffffffe00,
  0xffffffffffffff00, 0xffffffffffffff00,
  0xffffffffffffff80, 0xffffffffffffff80,
  0xffffffffffffffc0, 0xffffffffffffffc0,
  0xffffffffffffffe0, 0xffffffffffffffe0,
  0xfffffffffffffff0, 0xfffffffffffffff0,
  0xfffffffffffffff8, 0xfffffffffffffff8,
  0xfffffffffffffffc, 0xfffffffffffffffc,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffc0000001, 0xffffffffc0000001,
  0xffffffffe0000000, 0xffffffffe0000000,
  0xfffffffff0000000, 0xfffffffff0000000,
  0xfffffffff8000000, 0xfffffffff8000000,
  0xfffffffffc000000, 0xfffffffffc000000,
  0xfffffffffe000000, 0xfffffffffe000000,
  0xffffffffff000000, 0xffffffffff000000,
  0xffffffffff800000, 0xffffffffff800000,
  0xffffffffffc00000, 0xffffffffffc00000,
  0xffffffffffe00000, 0xffffffffffe00000,
  0xfffffffffff00000, 0xfffffffffff00000,
  0xfffffffffff80000, 0xfffffffffff80000,
  0xfffffffffffc0000, 0xfffffffffffc0000,
  0xfffffffffffe0000, 0xfffffffffffe0000,
  0xffffffffffff0000, 0xffffffffffff0000,
  0xffffffffffff8000, 0xffffffffffff8000,
  0xffffffffffffc000, 0xffffffffffffc000,
  0xffffffffffffe000, 0xffffffffffffe000,
  0xfffffffffffff000, 0xfffffffffffff000,
  0xfffffffffffff800, 0xfffffffffffff800,
  0xfffffffffffffc00, 0xfffffffffffffc00,
  0xfffffffffffffe00, 0xfffffffffffffe00,
  0xffffffffffffff00, 0xffffffffffffff00,
  0xffffffffffffff80, 0xffffffffffffff80,
  0xffffffffffffffc0, 0xffffffffffffffc0,
  0xffffffffffffffe0, 0xffffffffffffffe0,
  0xfffffffffffffff0, 0xfffffffffffffff0,
  0xfffffffffffffff8, 0xfffffffffffffff8,
  0xfffffffffffffffc, 0xfffffffffffffffc,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffc0000001, 0xffffffffffffc000,
  0xffffffffe0000000, 0xffffffffffffe000,
  0xfffffffff0000000, 0xfffffffffffff000,
  0xfffffffff8000000, 0xfffffffffffff800,
  0xfffffffffc000000, 0xfffffffffffffc00,
  0xfffffffffe000000, 0xfffffffffffffe00,
  0xffffffffff000000, 0xffffffffffffff00,
  0xffffffffff800000, 0xffffffffffffff80,
  0xffffffffffc00000, 0xffffffffffffffc0,
  0xffffffffffe00000, 0xffffffffffffffe0,
  0xfffffffffff00000, 0xfffffffffffffff0,
  0xfffffffffff80000, 0xfffffffffffffff8,
  0xfffffffffffc0000, 0xfffffffffffffffc,
  0xfffffffffffe0000, 0xfffffffffffffffe,
  0xffffffffffff0000, 0xffffffffffffffff,
  0xffffffffffff8000, 0xffffffffffffffff,
  0xffffffffffffc000, 0xffffffffffffffff,
  0xffffffffffffe000, 0xffffffffffffffff,
  0xfffffffffffff000, 0xffffffffffffffff,
  0xfffffffffffff800, 0xffffffffffffffff,
  0xfffffffffffffc00, 0xffffffffffffffff,
  0xfffffffffffffe00, 0xffffffffffffffff,
  0xffffffffffffff00, 0xffffffffffffffff,
  0xffffffffffffff80, 0xffffffffffffffff,
  0xffffffffffffffc0, 0xffffffffffffffff,
  0xffffffffffffffe0, 0xffffffffffffffff,
  0xfffffffffffffff0, 0xffffffffffffffff,
  0xfffffffffffffff8, 0xffffffffffffffff,
  0xfffffffffffffffc, 0xffffffffffffffff,
  0xfffffffffffffffe, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffc000, 0xffffffffffffc000,
  0xffffffffffffe000, 0xffffffffffffe000,
  0xfffffffffffff000, 0xfffffffffffff000,
  0xfffffffffffff800, 0xfffffffffffff800,
  0xfffffffffffffc00, 0xfffffffffffffc00,
  0xfffffffffffffe00, 0xfffffffffffffe00,
  0xffffffffffffff00, 0xffffffffffffff00,
  0xffffffffffffff80, 0xffffffffffffff80,
  0xffffffffffffffc0, 0xffffffffffffffc0,
  0xffffffffffffffe0, 0xffffffffffffffe0,
  0xfffffffffffffff0, 0xfffffffffffffff0,
  0xfffffffffffffff8, 0xfffffffffffffff8,
  0xfffffffffffffffc, 0xfffffffffffffffc,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffc000, 0xffffffffffffc001,
  0xffffffffffffe000, 0xffffffffffffe000,
  0xfffffffffffff000, 0xfffffffffffff000,
  0xfffffffffffff800, 0xfffffffffffff800,
  0xfffffffffffffc00, 0xfffffffffffffc00,
  0xfffffffffffffe00, 0xfffffffffffffe00,
  0xffffffffffffff00, 0xffffffffffffff00,
  0xffffffffffffff80, 0xffffffffffffff80,
  0xffffffffffffffc0, 0xffffffffffffffc0,
  0xffffffffffffffe0, 0xffffffffffffffe0,
  0xfffffffffffffff0, 0xfffffffffffffff0,
  0xfffffffffffffff8, 0xfffffffffffffff8,
  0xfffffffffffffffc, 0xfffffffffffffffc,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffc001, 0xffffffffffffc001,
  0xffffffffffffe000, 0xffffffffffffe000,
  0xfffffffffffff000, 0xfffffffffffff000,
  0xfffffffffffff800, 0xfffffffffffff800,
  0xfffffffffffffc00, 0xfffffffffffffc00,
  0xfffffffffffffe00, 0xfffffffffffffe00,
  0xffffffffffffff00, 0xffffffffffffff00,
  0xffffffffffffff80, 0xffffffffffffff80,
  0xffffffffffffffc0, 0xffffffffffffffc0,
  0xffffffffffffffe0, 0xffffffffffffffe0,
  0xfffffffffffffff0, 0xfffffffffffffff0,
  0xfffffffffffffff8, 0xfffffffffffffff8,
  0xfffffffffffffffc, 0xfffffffffffffffc,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffc001, 0xffffffffffffffc0,
  0xffffffffffffe000, 0xffffffffffffffe0,
  0xfffffffffffff000, 0xfffffffffffffff0,
  0xfffffffffffff800, 0xfffffffffffffff8,
  0xfffffffffffffc00, 0xfffffffffffffffc,
  0xfffffffffffffe00, 0xfffffffffffffffe,
  0xffffffffffffff00, 0xffffffffffffffff,
  0xffffffffffffff80, 0xffffffffffffffff,
  0xffffffffffffffc0, 0xffffffffffffffff,
  0xffffffffffffffe0, 0xffffffffffffffff,
  0xfffffffffffffff0, 0xffffffffffffffff,
  0xfffffffffffffff8, 0xffffffffffffffff,
  0xfffffffffffffffc, 0xffffffffffffffff,
  0xfffffffffffffffe, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffc0, 0xffffffffffffffc0,
  0xffffffffffffffe0, 0xffffffffffffffe0,
  0xfffffffffffffff0, 0xfffffffffffffff0,
  0xfffffffffffffff8, 0xfffffffffffffff8,
  0xfffffffffffffffc, 0xfffffffffffffffc,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffc0, 0xffffffffffffffc1,
  0xffffffffffffffe0, 0xffffffffffffffe0,
  0xfffffffffffffff0, 0xfffffffffffffff0,
  0xfffffffffffffff8, 0xfffffffffffffff8,
  0xfffffffffffffffc, 0xfffffffffffffffc,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffc1, 0xffffffffffffffc1,
  0xffffffffffffffe0, 0xffffffffffffffe0,
  0xfffffffffffffff0, 0xfffffffffffffff0,
  0xfffffffffffffff8, 0xfffffffffffffff8,
  0xfffffffffffffffc, 0xfffffffffffffffc,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffc1, 0xffffffffffffffe0,
  0xffffffffffffffe0, 0xfffffffffffffff0,
  0xfffffffffffffff0, 0xfffffffffffffff8,
  0xfffffffffffffff8, 0xfffffffffffffffc,
  0xfffffffffffffffc, 0xfffffffffffffffe,
  0xfffffffffffffffe, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffe0, 0xfffffffffffffffe,
  0xfffffffffffffff0, 0xffffffffffffffff,
  0xfffffffffffffff8, 0xffffffffffffffff,
  0xfffffffffffffffc, 0xffffffffffffffff,
  0xfffffffffffffffe, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xfffffffffffffffe, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
};
const unsigned kExpectedCount_NEON_sshr_2D_2OPIMM = 2560;

#endif  // VIXL_SIM_SSHR_2D_2OPIMM_TRACE_AARCH64_H_
